SystemOrganization addCategory: #'Seaside-Tests-Pharo40-Core'!

WAEncoderTest subclass: #WAEncoderLatin1Test
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Pharo40-Core'!

!WAEncoderLatin1Test methodsFor: 'configuration' stamp: 'pmm 8/15/2011 08:34'!
createCodec
	^ GRCodec forEncoding: 'iso-8859-1'! !

!WAEncoderLatin1Test methodsFor: 'tests' stamp: 'pmm 8/14/2012 20:04'!
testEncodedLatin1Url
	self
		assert: (String
			with: Character space
			with: (Character codePoint: 233)
			with: (Character codePoint: 228))
		urlEncodedGives: '%20%E9%E4'! !

!WAEncoderLatin1Test methodsFor: 'tests' stamp: 'pmm 8/14/2012 20:04'!
testEncodedLatin1Xml
	| string |
	string := String
		with: Character space
		with: (Character codePoint: 233)
		with: (Character codePoint: 228).
	self
		assert: string
		xmlEncodedGives: string! !

WAEncoderTest subclass: #WAEncoderUnicodeTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Pharo40-Core'!

!WAEncoderUnicodeTest methodsFor: 'configuration' stamp: 'jf 9/30/2009 00:27'!
createCodec
	^ GRCodec forEncoding: 'utf-8'! !

!WAEncoderUnicodeTest methodsFor: 'tests' stamp: 'pmm 8/14/2012 20:01'!
testEncodedLatin1Url
	self
		assert: (String
			with: Character space
			with: (Character codePoint: 233)
			with: (Character codePoint: 228))
		urlEncodedGives: '%20%C3%A9%C3%A4'! !

!WAEncoderUnicodeTest methodsFor: 'tests' stamp: 'pmm 8/14/2012 20:03'!
testEncodedSupplementaryMultilingualPlane
	"The Supplementary Multilingual Plane (SMP: Plane 1, U+010000 - U+01FFFF)
	http://www.unicode.org/charts/PDF/U10140.pdf
	Ancient Greek Zero Sign"
	| zero |
	zero := (Character codePoint: 65930) greaseString.
	self 
		assert: zero
		xmlEncodedGives: zero! !

!WAEncoderUnicodeTest methodsFor: 'tests' stamp: 'pmm 8/14/2012 20:03'!
testEncodedSupplementaryMultilingualPlaneUrl
	"The Supplementary Multilingual Plane (SMP: Plane 1, U+010000 - U+01FFFF)
	http://www.unicode.org/charts/PDF/U10140.pdf
	Ancient Greek Zero Sign"
	| zero |
	zero := (Character codePoint: 65930) greaseString.
	self 
		assert: zero
		urlEncodedGives: '%F0%90%86%8A'! !

!WAEncoderUnicodeTest methodsFor: 'tests' stamp: 'pmm 8/14/2012 20:02'!
testEncodedUnicode
	"this makes sure the encoder doesn't fall on the nose with unicode"
	| hiraA hiraO hiraAO ea |
	ea := String 
		with: (Character codePoint: 233)
		with: (Character codePoint: 228).
	self 
		assert: ea
		xmlEncodedGives: ea.
	hiraA := (Character codePoint: 12354) greaseString.	"HIRAGANA LETTER A"
	hiraO := (Character codePoint: 12362) greaseString.	"HIRAGANA LETTER O"
	hiraAO := hiraA , hiraO.
	self 
		assert: hiraA
		xmlEncodedGives: hiraA.
	self 
		assert: hiraO
		xmlEncodedGives: hiraO.
	self 
		assert: hiraAO
		xmlEncodedGives: hiraAO! !

!WAEncoderUnicodeTest methodsFor: 'tests' stamp: 'pmm 8/14/2012 20:02'!
testEncodedUnicodeUrl
	"this makes sure the encoder doesn't fall on the nose with unicode"
	| hiraA hiraO hiraAO ea |
	ea := String 
		with: (Character codePoint: 233)
		with: (Character codePoint: 228).
	self 
		assert: ea
		urlEncodedGives: '%C3%A9%C3%A4'.
	hiraA := (Character codePoint: 12354) greaseString.	"HIRAGANA LETTER A"
	hiraO := (Character codePoint: 12362) greaseString.	"HIRAGANA LETTER O"
	hiraAO := hiraA , hiraO.
	self 
		assert: hiraA
		urlEncodedGives: '%E3%81%82'.
	self 
		assert: hiraO
		urlEncodedGives: '%E3%81%8A'.
	self 
		assert: hiraAO
		urlEncodedGives: '%E3%81%82' , '%E3%81%8A'! !

WAEncoderUnicodeTest subclass: #WAPharoEncoderTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Pharo40-Core'!

!WAPharoEncoderTest methodsFor: 'private' stamp: 'pmm 8/15/2011 21:08'!
assert: aString next: anInteger startingAt: startIndex encoder: aClass gives: anEncodedString
	| actual |
	actual := String streamContents: [ :stream |
		(aClass on: stream codec: self requestContext codec)
			greaseNext: anInteger putAll: aString startingAt: startIndex ].
	self assert: actual = anEncodedString! !

!WAPharoEncoderTest methodsFor: 'tests' stamp: 'pmm 2/19/2012 15:48'!
testGreaseNextPutAllStartingAt
	self
		assert: '$(&quot;#seastar&quot;).animate({&quot;left&quot;:&quot;-=100px&quot;},{})'
		next: 13
		startingAt: 4
		encoder: self xmlEncoderClass
		gives:  'quot;#seastar'.! !

!WAPharoEncoderTest methodsFor: 'tests' stamp: 'pmm 8/15/2011 08:19'!
testIncludesUnsafeUrlCharacter
	| encoder unsafeCharacters |
	encoder := WAPharoUrlEncoder on: (WriteStream on: String new).
	unsafeCharacters := ((0 to: 127)
		collect: [ :each | Character codePoint: each ])
		reject: [ :each | 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789-_.~' includes: each ].
	
	unsafeCharacters do: [ :each |
		self assert: (encoder includesUnsafeCharacter: (String with: each)).
		self assert: (encoder includesUnsafeCharacter: 'a', (String with: each)).
		self assert: (encoder includesUnsafeCharacter: (String with: each), 'a') ].
	
	"make sure the method does not blow up on empty strings"
	encoder includesUnsafeCharacter: ''! !

!WAPharoEncoderTest methodsFor: 'tests' stamp: 'pmm 8/15/2011 08:20'!
testIncludesUnsafeXmlCharacter
	| encoder |
	encoder := WAPharoXmlEncoder on: (WriteStream on: String new).
	'"<&' do: [ :each |
		self assert: (encoder includesUnsafeCharacter: (String with: each)).
		self assert: (encoder includesUnsafeCharacter: 'a', (String with: each)).
		self assert: (encoder includesUnsafeCharacter: (String with: each), 'a') ].
	
	"just make sure the method doesn't blow up on empty strings"
	encoder includesUnsafeCharacter: ''.! !

!WAPharoEncoderTest methodsFor: 'tests' stamp: 'pmm 4/21/2012 20:35'!
testUrlGreaseNextPutAllStartingAt
	self assert: 'ab' next: 1 startingAt: 1 encoder: self urlEncoderClass gives:  'a'.
	self assert: 'a b' next: 1 startingAt: 1 encoder: self urlEncoderClass gives:  'a'.
	self assert: 'a b' next: 2 startingAt: 1 encoder: self urlEncoderClass gives:  'a%20'.
	self assert: 'a b' next: 1 startingAt: 2 encoder: self urlEncoderClass gives:  '%20'.
	self assert: 'a b' next: 2 startingAt: 2 encoder: self urlEncoderClass gives:  '%20b'.
	self assert: 'a  ' next: 2 startingAt: 2 encoder: self urlEncoderClass gives:  '%20%20'.
	self assert: 'ab b ' next: 3 startingAt: 2 encoder: self urlEncoderClass gives:  'b%20b'! !

!WAPharoEncoderTest methodsFor: 'tests' stamp: 'pmm 4/21/2012 20:52'!
testXmlGreaseNextPutAllStartingAt
	self assert: 'ab' next: 1 startingAt: 1 encoder: self xmlEncoderClass gives:  'a'.
	self assert: 'a<b' next: 1 startingAt: 1 encoder: self xmlEncoderClass gives:  'a'.
	self assert: 'a<b' next: 2 startingAt: 1 encoder: self xmlEncoderClass gives:  'a&lt;'.
	self assert: 'a<b' next: 1 startingAt: 2 encoder: self xmlEncoderClass gives:  '&lt;'.
	self assert: 'a<b' next: 2 startingAt: 2 encoder: self xmlEncoderClass gives:  '&lt;b'.
	self assert: 'a<<b' next: 2 startingAt: 2 encoder: self xmlEncoderClass gives:  '&lt;&lt;'.
	self assert: 'ab<b<' next: 3 startingAt: 2 encoder: self xmlEncoderClass gives:  'b&lt;b'! !

!WAPharoEncoderTest methodsFor: 'private' stamp: 'pmm 8/15/2011 08:21'!
urlEncoderClass
	^ WAPharoUrlEncoder! !

!WAPharoEncoderTest methodsFor: 'private' stamp: 'pmm 8/15/2011 08:21'!
xmlEncoderClass
	^ WAPharoXmlEncoder! !

TestCase subclass: #WAFormTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Pharo40-Core'!

!WAFormTestCase class methodsFor: 'testing' stamp: 'jf 10/6/2008 15:28'!
isAbstract
	^ self name = #WAFormTestCase! !

!WAFormTestCase methodsFor: 'private' stamp: 'jf 10/6/2008 15:21'!
formClassExists
	^ Smalltalk hasClassNamed: #Form! !

!WAFormTestCase methodsFor: 'private' stamp: 'lr 7/25/2011 19:53'!
sampleForm
	^ (Smalltalk classNamed: #Form)
		extent: 16@16
		depth: 1
		fromArray: #( 0 0 0 50331648 25165824 12582912 281018368 415236096 264241152 132120576 7340032 3670016 1572864 0 0 0)
		offset: 0@0! !

WAFormTestCase subclass: #WAPharoDocumentHandlerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Pharo40-Core'!

!WAPharoDocumentHandlerTest methodsFor: 'tests' stamp: 'jf 7/31/2009 09:38'!
testForm
	| handler context |
	self formClassExists ifFalse: [ ^ self ].
	
	handler := WADocumentHandler
		document: self sampleForm
		mimeType: self sampleForm defaultMimeType
		fileName: nil.
	
	context := WARequestContext request: WARequest new response: WABufferedResponse new.
	[ handler handle: context ] on: WAResponseNotification do: [ :n | ].
	
	self assert: context response notNil! !

!WAPharoDocumentHandlerTest methodsFor: 'tests' stamp: 'pmm 8/6/2011 15:47'!
testFormWithMimeTypeGif
	"Test that requesting a form as GIF actually results in a GIF"
	| handler |
	self formClassExists ifFalse: [ ^ self ].
	
	handler := WADocumentHandler
		document: self sampleForm
		mimeType: WAMimeType imageGif
		fileName: nil.
	
	self assert: (handler document contents beginsWithSubCollection: #(16r47 16r49 16r46 16r38) asByteArray) "GIF Magic number"! !

!WAPharoDocumentHandlerTest methodsFor: 'tests' stamp: 'pmm 8/6/2011 15:47'!
testFormWithMimeTypeJpeg
	"Test that requesting a form as JPEG actually results in a JPEG"
	| handler |
	self formClassExists ifFalse: [ ^ self ].
	
	handler := WADocumentHandler
		document: self sampleForm
		mimeType: WAMimeType imageJpeg
		fileName: nil.
	
	self assert: (handler document contents beginsWithSubCollection: #(16rFF 16rD8 16rFF 16rE0) asByteArray) "JPEG Magic number"! !

!WAPharoDocumentHandlerTest methodsFor: 'tests' stamp: 'pmm 6/19/2010 09:14'!
testFormWithoutMimeType
	"Test that requesting a form without a mime type works"
	| handler |
	self formClassExists ifFalse: [ ^ self ].
	
	handler := WADocumentHandler
		document: self sampleForm
		mimeType: nil
		fileName: nil.
	
	self assert: handler document contents isEmptyOrNil not! !

WAFormTestCase subclass: #WAPharoMimeDocumentTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Pharo40-Core'!

!WAPharoMimeDocumentTest methodsFor: 'tests' stamp: 'JohanBrichau 4/19/2014 09:19'!
testAsMIMEDocumentForm
	| form document |
	self formClassExists ifFalse: [ ^ self ].
	
	form := self sampleForm.
	document := form seasideMimeDocument.
	self assert: document contentType = WAMimeType imagePng.
	self assert: (document content isKindOf: ByteArray)! !

!WAPharoMimeDocumentTest methodsFor: 'tests' stamp: 'lr 10/18/2008 16:44'!
testAsMIMEDocumentFormColon
	| form document |
	self formClassExists ifFalse: [ ^ self ].
	
	form := self sampleForm.
	document := form seasideMimeDocumentType: WAMimeType imageJpeg.
	self assert: document contentType = WAMimeType imageJpeg.
	self assert: (document content isKindOf: ByteArray)! !

!WAPharoMimeDocumentTest methodsFor: 'tests' stamp: 'jf 9/30/2009 01:10'!
testAsMIMEDocumentFormColonString
	| form document |
	self formClassExists ifFalse: [ ^ self ].
	form := self sampleForm.
	document := form seasideMimeDocumentType: WAMimeType imageJpeg greaseString.
	self assert: document contentType = WAMimeType imageJpeg.
	self assert: (document content isKindOf: ByteArray)! !

!WAPharoMimeDocumentTest methodsFor: 'tests' stamp: 'jf 10/6/2008 15:24'!
testAsMIMEDocumentFormUnknown
	| form |
	self formClassExists ifFalse: [ ^ self ].
	
	form := self sampleForm.
	self should: [ form seasideMimeDocumentType: 'foo/bar' ] raise: Error.
	self should: [ form seasideMimeDocumentType: 'foo/bar' seasideMimeType ] raise: Error.
	self should: [ form seasideMimeDocumentType: 'image/zork' ] raise: Error.
	self should: [ form seasideMimeDocumentType: 'image/zork' seasideMimeType ] raise: Error.! !

!WAPharoMimeDocumentTest methodsFor: 'tests' stamp: 'JohanBrichau 4/19/2014 09:19'!
testAsMIMEDocumentMorph
	| morph document |
	morph := EllipseMorph new
		color: Color red;
		borderWidth: 1;
		borderColor: Color black;
		extent: 12 @ 12;
		yourself.
	document := morph seasideMimeDocument.
	self assert: document contentType = WAMimeType imagePng.
	self assert: (document content isKindOf: ByteArray)! !

!WAPharoMimeDocumentTest methodsFor: 'tests' stamp: 'pmm 7/30/2010 06:43'!
testAsMIMEDocumentMorphColol
	| morph document |
	morph := EllipseMorph new
		color: Color red;
		borderWidth: 1;
		borderColor: Color black;
		extent: 12 @ 12;
		yourself.
	document := morph seasideMimeDocumentType: WAMimeType imageJpeg.
	self assert: document contentType = WAMimeType imageJpeg.
	self assert: (document content isKindOf: ByteArray)! !

!WAPharoMimeDocumentTest methodsFor: 'tests' stamp: 'lr 10/18/2008 16:45'!
testAsMIMEDocumentStream
	| document |
	document := 'dolphin' readStream seasideMimeDocument.
	self assert: document contentType = WAMimeType textPlain.
	self assert: document content = 'dolphin'! !

!WAPharoMimeDocumentTest methodsFor: 'tests' stamp: 'lr 10/18/2008 16:45'!
testAsMIMEDocumentStreamColon
	| document |
	document := 'monkey' readStream seasideMimeDocument.
	document mimeType: 'text/html'.
	self assert: document contentType = WAMimeType textHtml.
	self assert: document content = 'monkey'! !

!WAPharoMimeDocumentTest methodsFor: 'tests' stamp: 'pmm 6/19/2010 08:53'!
testBinaryStreamSeasideMimeDocumentType
	| document mpeg |
	mpeg := WAMimeType main: 'audio' sub: 'mpeg'.
	document :=  #(1 2 3 4) asByteArray readStream seasideMimeDocumentType: mpeg.
	self assert: document mimeType = mpeg.
	self assert: document contents = #(1 2 3 4) asByteArray ! !

!WAPharoMimeDocumentTest methodsFor: 'tests' stamp: 'pmm 6/19/2010 08:53'!
testTextStreamSeasideMimeDocumentType
	| document csv |
	csv := WAMimeType main: 'text' sub: 'csv'.
	document := 'foo,bar' readStream seasideMimeDocumentType: csv.
	self assert: document mimeType = csv.
	self assert: document contents = 'foo,bar'! !

!WAFileLibraryTest methodsFor: '*Seaside-Tests-Pharo40-Core' stamp: 'JohanBrichau 5/18/2014 09:50'!
runCase
	GRPlatform current doSilently:  [ super performTest ]! !

!GRPackage class methodsFor: '*Seaside-Tests-Pharo40-Core' stamp: 'StephanEggermont 7/2/2014 18:52'!
seasideTestsPharo40Core
	^ self new
		name: 'Seaside-Tests-Pharo40-Core';
		addDependency: 'Seaside-Pharo20-Core';
		addDependency: 'Seaside-Tests-Core';
		url: #seasideUrl;
		yourself! !

WAContextTest subclass: #WAGenericCodecTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Pharo40-Core'!

!WAGenericCodecTest methodsFor: 'private' stamp: 'lr 7/25/2011 19:53'!
asString: aCollectionOfIntegers
	^ String streamContents: [ :stream |
		aCollectionOfIntegers do: [ :each |
			stream nextPut: (Character codePoint: each) ] ]! !

!WAGenericCodecTest methodsFor: 'private' stamp: 'pmm 7/17/2009 21:27'!
latin1String
	^ self asString: #(220 98 232 114 115 116 114 238 241 103 233)! !

!WAGenericCodecTest methodsFor: 'private' stamp: 'pmm 7/17/2009 21:29'!
macromanString
	^ self asString: #(134 98 143 114 115 116 114 148 150 103 142)! !

!WAGenericCodecTest methodsFor: 'tests' stamp: 'pmm 8/16/2010 09:22'!
testGenericCodecAll
	TextConverter allEncodingNames do: [ :name | 
		(#('utf-8'), GRPharoLatin1Codec supportedEncodingNames includes: name) ifFalse: [
			| codec |
			codec := GRCodec forEncoding: name.
			self assert: codec name = name.
			self assert: (codec isKindOf: GRPharoGenericCodec) ] ]! !

!WAGenericCodecTest methodsFor: 'tests' stamp: 'jf 9/30/2009 00:46'!
testGenericCodecMacRoman
	| codec |
	codec := GRCodec forEncoding: 'mac-roman'.
	self assert: (codec isKindOf: GRPharoGenericCodec).
	self assert: codec name = 'mac-roman'.
	self assert: codec url name = 'utf-8'.
	self assert: (codec url isKindOf: GRPharoUtf8Codec).
	self assert: (codec encode: self latin1String) = self macromanString.
	self assert: (codec url encode: self latin1String) = self utf8String.
	self assert: (codec decode: self macromanString) = self latin1String.
	self assert: (codec url decode: self utf8String) = self latin1String! !

!WAGenericCodecTest methodsFor: 'tests' stamp: 'pmm 8/6/2011 15:49'!
testGenericCodecUtf16be
	| codec bom |
	codec := GRCodec forEncoding: 'utf-16'.
	self assert: (codec isKindOf: GRPharoGenericCodec).
	bom := self asString: #(254 255).
	self assert: codec name = 'utf-16'.
	self assert: codec url name = 'utf-8'.
	self assert: (codec url isKindOf: GRPharoUtf8Codec).
	self assert: (codec encode: self latin1String) = self utf16beString.
	self assert: (codec url encode: self latin1String) = self utf8String.
	self assert: (codec decode: self utf16beString) = self latin1String.
	self assert: (codec decode: bom , self utf16beString) = self latin1String.
	self assert: (codec url decode: self utf8String) = self latin1String! !

!WAGenericCodecTest methodsFor: 'tests' stamp: 'pmm 8/6/2011 15:49'!
testGenericCodecUtf16le
	| codec bom |
	codec := GRCodec forEncoding: 'utf-16'.
	self assert: (codec isKindOf: GRPharoGenericCodec).
	bom := self asString: #(255 254).
	self assert: codec name = 'utf-16'.
	self assert: codec url name = 'utf-8'.
	self assert: (codec url isKindOf: GRPharoUtf8Codec).
	self assert: (codec encode: self latin1String) = self utf16beString.
	self assert: (codec url encode: self latin1String) = self utf8String.
	self assert: (codec decode: bom , self utf16leString) = self latin1String.
	self assert: (codec url decode: self utf8String) = self latin1String! !

!WAGenericCodecTest methodsFor: 'tests' stamp: 'jf 9/30/2009 00:45'!
testInstantiateUtf8
	self 
		should: [ GRPharoGenericCodec forEncoding: 'utf-8' ]
		raise: GRUnsupportedEncodingError! !

!WAGenericCodecTest methodsFor: 'tests' stamp: 'pmm 8/16/2010 00:49'!
testSqueakCodecLatin1
	"tests the codec for 'lating-1' and #converter"
	#('iso-8859-1' 'ISO-8859-1' 'latin-1' ) do: [ :each | 
		| codec |
		codec := GRCodec forEncoding: each.
		self assert: codec name = each.
		self assert: codec url name = each.
		self assert: (codec encode: self latin1String) = self latin1String.
		self assert: (codec url encode: self latin1String) = self latin1String.
		self assert: (codec decode: self latin1String) = self latin1String.
		self assert: (codec url decode: self latin1String) = self latin1String ]! !

!WAGenericCodecTest methodsFor: 'private' stamp: 'pmm 7/17/2009 21:32'!
utf16beString
	^ self asString: #(0 220 0 98 0 232 0 114 0 115 0 116 0 114 0 238 0 241 0 103 0 233)! !

!WAGenericCodecTest methodsFor: 'private' stamp: 'pmm 7/17/2009 21:32'!
utf16leString
	^ self asString: #(220 0 98 0 232 0 114 0 115 0 116 0 114 0 238 0 241 0 103 0 233 0)! !

!WAGenericCodecTest methodsFor: 'private' stamp: 'pmm 7/17/2009 21:30'!
utf8String
	^ self asString: #(195 156 98 195 168 114 115 116 114 195 174 195 177 103 195 169)! !

WAContextTest subclass: #WAPharoFileLibraryTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Pharo40-Core'!

!WAPharoFileLibraryTest methodsFor: 'private' stamp: 'pmm 2/12/2011 09:08'!
supportsSwitchToNewCompiler
	Smalltalk at: #PragmaSetting ifAbsent: [ ^ true ].
	^ false! !

!WAPharoFileLibraryTest methodsFor: 'tests' stamp: 'StephanEggermont 7/2/2014 16:10'!
testAddAllFilesIn
	| workingDirectory directoryName directory library |
	directoryName := 'XXXUsedBySeasideTests'.
	workingDirectory := FileSystem disk workingDirectory.
	GRPlatform current ensureExistenceOfFolder: directoryName.
	directory :=workingDirectory / directoryName.
	[ [
		(directory / '.Seaside_Store') ensureCreateFile .
		(directory / 'foo') ensureCreateFile.
		GRPlatform current doSilently: [
			library := WAFileLibrary
				subclass: #XXXTestFileLibrary
				instanceVariableNames: ''
				classVariableNames: ''
				poolDictionaries: ''
				category: 'Uncategorized'.
		[ library addAllFilesIn: directory fullName.
			self assert: library selectors size = 1 ] "reject .Seaside_Store"
				ensure: [ library removeFromSystem ] ] ]
			ensure: [ directory children do: [ :each | each delete ] ] ]
			ensure: [ directory delete ]! !

!WAPharoFileLibraryTest methodsFor: 'tests' stamp: 'pmm 6/26/2011 14:14'!
testCompileByteArrayLiteralSource
	| library data file source expected |
	GRPharoPlatform current useByteArrayLiterals ifFalse: [ ^ self ].
	self 
		useCompileUseNewCompiler: true
		during: [
			self assert: GRPharoPlatform current useByteArrayLiterals.
			library := WATestingFiles default.
			data := (1 to: 255) asByteArray.
			file := WAFile new
				contentType: WAMimeType imageJpeg;
				contents: data;
				fileName: 'demo.jpeg';
				yourself.
			library addFile: file.
			
			[ source := WATestingFiles sourceCodeAt: #demoJpeg.
			expected := 'demoJpeg
	^ #[1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255]'.
			self assert: source greaseString = expected ]
				ensure: [ library removeFile: file fileName ] ]! !

!WAPharoFileLibraryTest methodsFor: 'tests' stamp: 'pmm 6/26/2011 14:14'!
testCompileByteArrayWithCacheSource
	| library data file source expected |
	self 
		useCompileUseNewCompiler: false
		during: [
			self deny: GRPharoPlatform current useByteArrayLiterals.
			library := WATestingFiles default.
			data := (1 to: 255) asByteArray.
			file := WAFile new
				contentType: WAMimeType imageJpeg;
				contents: data;
				fileName: 'demo.jpeg';
				yourself.
			library addFile: file.
			
			[ source := WATestingFiles sourceCodeAt: #demoJpeg.
			expected := 'demoJpeg
	^ #(1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255) asByteArray'.
			self assert: source greaseString = expected ]
				ensure: [ library removeFile: file fileName ] ]! !

!WAPharoFileLibraryTest methodsFor: 'private' stamp: 'pmm 2/12/2011 09:08'!
useCompileUseNewCompiler: aBoolean during: aBlock
	| oldValue |
	self supportsSwitchToNewCompiler
		ifFalse: [ ^ self ].
	oldValue := GRPharoPlatform current useByteArrayLiterals.
	[ (Smalltalk at: #Preferences) setPreference: #compileUseNewCompiler toValue: aBoolean.
	aBlock value ]
		ensure: [
			GRPharoPlatform current useByteArrayLiterals ifTrue: [
				Preferences setPreference: #compileUseNewCompiler toValue: oldValue ] ]! !
